@@ -1,12 +1,23 @@
 import uuid
 from typing import Any
 from django.db import models
-from django.core.exceptions import ValidationError
-from django.utils.translation import gettext_lazy as _
-from vanoma_api_utils.phone_numbers import is_valid_number
+from .validators import validate_number
 
 
-class PrimaryKeyField(models.UUIDField):
+class StringField(models.CharField):
+    """
+    Custom field with pre-defined max length to be used as primary key,
+    for pk referencing purposes, or anywhere else a short string makes sense.
+    The max length is determined based on the length of UUID. Typically
+    UUID have 36 characters but we added 4 more for extra breathing room.
+    """
+
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        kwargs["max_length"] = 40
+        super().__init__(*args, **kwargs)
+
+
+class PrimaryKeyField(StringField):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         kwargs["editable"] = False
         kwargs["primary_key"] = True
@@ -14,20 +25,7 @@ class PrimaryKeyField(models.UUIDField):
         super().__init__(*args, **kwargs)
 
 
-class StringField(models.CharField):
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
-        kwargs["max_length"] = 150
-        super().__init__(*args, **kwargs)
-
-
 class PhoneNumberField(StringField):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
-        kwargs["validators"] = [PhoneNumberField.validate_number]
+        kwargs["validators"] = [validate_number]
         super().__init__(*args, **kwargs)
-
-    @staticmethod
-    def validate_number(phone_number: str) -> None:
-        if not is_valid_number(phone_number):
-            raise ValidationError(
-                _("Phone number {} is not valid.".format(phone_number))
-            )
