@@ -26,4 +26,4 @@ class BaseAPIClient(APIClient):
 
 
 class APIClientV1_0(BaseAPIClient):
-    ACCEPT_HEADER = "application/vnd.vanoma.api+json; version=1.0"
+    ACCEPT_HEADER = "application/json"
